# 导入所有任务模块，确保 @app.task 装饰器生效
# 这样第三方使用 celery_app 时，可以自动获取相应的 task 声明

from . import audio_transcription
from . import audio_format_conversion

# 导出所有任务模块，方便外部直接导入
__all__ = [
    'audio_transcription',
    'audio_format_conversion',
]


from celery import Celery
import os

CELERY_BROKER_URL = os.getenv('CELERY_BROKER_URL')
CELERY_RESULT_BACKEND = os.getenv('CELERY_RESULT_BACKEND')

app = Celery(
    'sskw_tasks',
    broker=CELERY_BROKER_URL,
    backend=CELERY_RESULT_BACKEND,
    include=['sskw.tasks'],
    timezone='UTC',
    enable_utc=True,
)

# 自动发现任务
app.autodiscover_tasks(['sskw.tasks'])


from sskw.tasks.celery_app import app
from sskw.tasks.models import AudioTranscriptionRequest, AudioTranscriptionResult

@app.task(name="sskw.audio.transcription.paraformer.cpu")
def audio_transcription_paraformer_cpu(input: AudioTranscriptionRequest) -> AudioTranscriptionResult:
    """
    语音转文字 funasr的 paraformer模型 cpu版本

    参数:
    - input (AudioTranscriptionRequest): 输入数据结构
    
    返回:
    - AudioTranscriptionResult: 处理结果
    """

    raise NotImplementedError("此任务必须在具体实现中完成")

@app.task(name="sskw.audio.transcription.paraformer.gpu")
def audio_transcription_paraformer_gpu(input: AudioTranscriptionRequest) -> AudioTranscriptionResult:
    """
    语音转文字 funasr的 paraformer模型 GPU版本
    
    参数:
    - input (AudioTranscriptionRequest): 输入数据结构
    
    返回:
    - AudioTranscriptionResult: 处理结果
    """

    raise NotImplementedError("此任务必须在具体实现中完成")


@app.task(name="sskw.audio.transcription.sensevoice.cpu")
def audio_transcription_sensevoice_cpu(input: AudioTranscriptionRequest) -> AudioTranscriptionResult:
    """
    语音转文字 funasr的 sensevoice模型 cpu版本
    
    参数:
    - input (AudioTranscriptionRequest): 输入数据结构
    
    返回:
    - AudioTranscriptionResult: 处理结果
    """

    raise NotImplementedError("此任务必须在具体实现中完成")

@app.task(name="sskw.audio.transcription.sensevoice.gpu")
def audio_transcription_sensevoice_gpu(input: AudioTranscriptionRequest) -> AudioTranscriptionResult:
    """
    语音转文字 funasr的 sensevoice模型 GPU版本
    
    参数:
    - input (AudioTranscriptionRequest): 输入数据结构
    
    返回:
    - AudioTranscriptionResult: 处理结果
    """

    raise NotImplementedError("此任务必须在具体实现中完成")


from pydantic import BaseModel
from typing import List, Dict


class AudioTranscriptionRequest(BaseModel):
    audio_urls: List[str]
    data_id: str    

class AudioTranscriptionResult(BaseModel):
    audio_urls: List[str]       #原始待转换的urls
    data_id: str                #透传的data_id
    result_url: str             #转写结果url地址
    merged_audio_url: str       #合并后或本身只有一个的对应的url地址


class AudioFormatConversionRequest(BaseModel):
    from_url: str
    from_format: str
    to_format: str
    data_id: str

class AudioFormatConversionResult(BaseModel):
    from_url: str
    from_format: str
    to_format: str
    data_id: str
    to_url: str




from sskw.tasks.celery_app import app
from sskw.tasks.models import AudioFormatConversionRequest, AudioFormatConversionResult

@app.task(name="sskw.audio.format.conversion")
def audio_format_conversion(input: AudioFormatConversionRequest) -> AudioFormatConversionResult:
    """
    音频数据格式转换
    
    参数:
    - input (AudioFormatConversionRequest): 输入数据结构
    
    返回:
    - AudioFormatConversionResult: 处理结果
    """

    raise NotImplementedError("此任务必须在具体实现中完成")